@@ -15,9 +15,8 @@
 #' @examples
 #' data(towns)
 #' st_centerish(towns)
-#' 
+#'
 st_centerish <- function(shp, epsg = 3857) {
-  
   cent <- geos_centerish(shp, epsg = epsg)
 
   sf::st_geometry(shp) <- sf::st_as_sfc(cent)
@@ -41,31 +40,30 @@ st_centerish <- function(shp, epsg = 3857) {
 #' @examples
 #' data(towns)
 #' geos_centerish(towns)
-#' 
+#'
 geos_centerish <- function(shp, epsg = 3857) {
-  
   shp <- make_planar_pair(x = shp, epsg = epsg)$x
-  
+
   cent <- geos::geos_centroid(shp)
-  
+
   if (nrow(shp) > 1) {
     outside <- !geos::geos_within(cent, shp)
-    
+
     if (any(outside)) {
       cent[outside] <- geos::geos_point_on_surface(shp[outside, ])
     }
   } else {
     outside <- !geos::geos_within(geom1 = cent, geom2 = shp)
-    
+
     if (is.na(outside)) {
       outside <- TRUE
     }
-    
+
     if (outside) {
       cent <- geos::geos_point_on_surface(shp)
     }
   }
-  
+
   cent
 }
 
@@ -85,12 +83,11 @@ geos_centerish <- function(shp, epsg = 3857) {
 #'
 #' @examples
 #' data(towns)
-#' st_centerish(towns)
-#' 
+#' st_circle_center(towns)
+#'
 st_circle_center <- function(shp, tolerance = 0.01, epsg = 3857) {
-  
   cent <- geos_circle_center(shp, tolerance = tolerance, epsg = epsg)
-  
+
   sf::st_geometry(shp) <- sf::st_as_sfc(cent)
   shp
 }
@@ -111,12 +108,10 @@ st_circle_center <- function(shp, tolerance = 0.01, epsg = 3857) {
 #'
 #' @examples
 #' data(towns)
-#' geos_centerish(towns)
-#' 
+#' geos_circle_center(towns)
+#'
 geos_circle_center <- function(shp, tolerance = 0.01, epsg = 3857) {
-  
   shp <- make_planar_pair(x = shp, epsg = epsg)$x
-  
-  geos::geos_centroid(geos::geos_maximum_inscribed_crc(shp))
-}
 
+  geos::geos_centroid(geos::geos_maximum_inscribed_crc(shp, tolerance = tolerance))
+}
